<?php
/**
 *
 * utils.php - Misc utils common to all aspects of the site
 *
 * SourceForge: Breaking Down the Barriers to Open Source Development
 * Copyright 1999-2001 (c) VA Linux Systems
 * http://sourceforge.net
 *
 * @version   $Id: utils.php,v 1.5 2002/05/28 15:08:27 arjenvanefferen Exp $
 *
 */
require_once(XOOPS_ROOT_PATH."/xf/include/phpmailer/class.phpmailer.php");

function util_unconvert_htmlspecialchars($string) {
	if (strlen($string) < 1) {
		return '';
	} else {
		$trans = get_html_translation_table(HTMLENTITIES, ENT_QUOTES);
		$trans = array_flip ($trans);
		$str = strtr ($string, $trans);
		return $str;
	}
}
/**
 * util_result_column_to_array() - Takes a result set and turns the optional column into an array
 *
 * @param		int		The result set ID
 * @param		int		The column
 * @resturns An array
 *
 */
function util_result_column_to_array($result, $col=0) {
  global $xoopsDB;
	/*
		Takes a result set and turns the optional column into
		an array
	*/
	$rows = $xoopsDB->getRowsNum($result);

	if ($rows > 0) {
		$arr=array();
		
		for ($i=0; $i<$rows; $i++) {
			$arr[$i] = unofficial_getDBResult($result,$i,$col);
		}
	} else {
		$arr=array();
	}

	return $arr;
}
/**
 * util_result_columns_to_assoc() - Takes a result set and turns the column pair into an associative array
 *
 * @param		string	The result set ID
 * @param		int		The column key
 * @param		int		The optional column value
 * @returns An associative array
 *
 */
function util_result_columns_to_assoc($result, $col_key=0, $col_val=1) {
  global $xoopsDB;
	$rows = $xoopsDB->getRowsNum($result);

	if ($rows > 0) {
		$arr=array();
		for ($i=0; $i<$rows; $i++) {
			$arr[unofficial_getDBResult($result,$i,$col_key)] = unofficial_getDBResult($result,$i,$col_val);
		}
	} else {
		$arr=array();
	}
	return $arr;
}

/**
 * show_priority_colors_key() - Show the priority colors legend
 *
 */
function show_priority_colors_key() {

	echo "<P><B>"._XF_PRIORITYCOLORS.":</B><BR>"
	    ."<TABLE BORDER='0'><TR>";

	for ($i=1; $i<10; $i++)
	{
		echo "<TD BGCOLOR='".get_priority_color($i)."'>".$i."</TD>";
	}
	echo "</tr></table>";
}

function validate_email ($address) {
	return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address));
}

function checkXFAdminPermissions ($error_on_failure='Access Denied')
{
  global $xoopsConfig, $xoopsUser;
	
  include_once($xoopsConfig['root_path']."class/xoopsmodule.php");
	include_once($xoopsConfig['root_path']."class/xoopsgroup.php");
	$xoopsModule = XoopsModule::getByDirname("xfmod");
	if ( !$xoopsModule ) {
		redirect_header($xoopsConfig['xoops_url']."/",2,"SOME SERIOUS ERROR OCCURED!! Where is the 'xfmod' module?!?!?!");
		exit();
	}
	if ( $xoopsUser ) {
		if ( !XoopsGroup::hasAccessRight($xoopsModule->mid(), $xoopsUser->groups()) ) {
			redirect_header($xoopsConfig['xoops_url']."/",2,$error_on_failure);
			exit();
		}
	} else {
		if ( !XoopsGroup::hasAccessRight($xoopsModule->mid(), 0) ) {
			redirect_header($xoopsConfig['xoops_url']."/",2,$error_on_failure);
			exit();
		}
	}
}

function xoopsForgeMail ($from, $fromname, $subject, $body, $to_arr, $bcc_arr, $cc_arr)
{
  global $xoopsForge;
	
  $mail = new phpmailer();

	switch ($xoopsForge['usemailer'])
	{
	  case 0: { // use SMTP
      $mail->IsSMTP();                                      // set mailer to use SMTP
      $mail->Host = $xoopsForge['parammail1'];        // specify main and backup server
		} break;
	  case 1: { // use Mail
      $mail->IsMail();
		} break;
	  case 2: { // use Sendmail
      $mail->IsSendmail();
			$mail->Sendmail = $xoopsForge['parammail1'];
		} break;
	  case 3: { // use QMail
      $mail->IsQMail();
			$mail->Sendmail = $xoopsForge['parammail1'];
		} break;
	}

  $mail->From = $from;
  $mail->FromName = $fromname;
	
  $mail->WordWrap = 80;                                 // set word wrap to 80 characters
  $mail->IsHTML(false);                                  // set email format to HTML

  $mail->Subject = $subject;
  $mail->Body    = $body;

	foreach ($to_arr as $email)
	  $mail->AddAddress($email);

	foreach ($bcc_arr as $email)
    $mail->AddBCC($email);

	foreach ($cc_arr as $email)
    $mail->AddCC($email);

	return ($mail->Send());
}

function  ShowResultSet($result,$title="Untitled",$linkify=false)  {
	global $group_id, $xoopsDB;

	if  ($result)  {
		$rows  =  $xoopsDB->getRowsNum($result);
		$cols  =  unofficial_getNumFields($result);

    echo "<table border='0' width='100%'>"
		    ."<tr class='bg2'><td colspan='".$cols."'><B style='font-size:14px;text-align:left;'>".$title."</B></td></tr>";

		/*  Create  the  headers  */
    echo "<tr class='bg2'>";
		for ($i=0; $i < $cols; $i++) {
		  
			echo "<td><B>".unofficial_getFieldName($result,  $i)."</B></TD>";
		}
		echo "</tr>";

		/*  Create the rows  */
		for ($j = 0; $j < $rows; $j++) {
			echo "<TR class='".($j%2>0?"bg1":"bg3")."'>";
			for ($i = 0; $i < $cols; $i++) {
				if ($linkify && $i == 0) {
					$link = '<A HREF="'.$PHP_SELF.'?';
					$linkend = '</A>';
					if ($linkify == "bug_cat") {
						$link .= 'group_id='.$group_id.'&bug_cat_mod=y&bug_cat_id='.unofficial_getDBResult($result, $j, 'bug_category_id').'">';
					} else if($linkify == "bug_group") {
						$link .= 'group_id='.$group_id.'&bug_group_mod=y&bug_group_id='.unofficial_getDBResult($result, $j, 'bug_group_id').'">';
					} else if($linkify == "patch_cat") {
						$link .= 'group_id='.$group_id.'&patch_cat_mod=y&patch_cat_id='.unofficial_getDBResult($result, $j, 'patch_category_id').'">';
					} else if($linkify == "support_cat") {
						$link .= 'group_id='.$group_id.'&support_cat_mod=y&support_cat_id='.unofficial_getDBResult($result, $j, 'support_category_id').'">';
					} else if($linkify == "pm_project") {
						$link .= 'group_id='.$group_id.'&project_cat_mod=y&project_cat_id='.unofficial_getDBResult($result, $j, 'group_project_id').'">';
					} else {
						$link = $linkend = '';
					}
				} else {
					$link = $linkend = '';
				}
				echo '<td>'.$link . unofficial_getDBResult($result,  $j,  $i) . $linkend.'</td>';
			}
			echo '</tr>';
		}
		echo '</table>';
	} else {
		echo $xoopsDB->error();
	}
}

/**
 * util_check_fileupload() - determines if a filename is appropriate for upload
 *
 * @param       string  The name of the file being uploaded
 */
function util_check_fileupload($filename) {

  /* Empty file is a valid file.
     This is because this function should be called
     unconditionally at the top of submit action processing
     and many forms have optional file upload. */
  if ($filename == 'none' || $filename == '') {
    return "OK";
  }

  /* This should be enough... */
  if (!is_uploaded_file($filename)) {
    return "!is_uploaded_file";
  }
  /* ... but we'd rather be paranoic */
	if (strstr($filename, '..')) {
		return "strstr(filename, '..')";
	}
	if (!is_file($filename)) {
		return "!is_file";
	}
	if (!file_exists($filename)) {
		return "!file_exists";
	}
	return "OK";
}

/**
 * GraphResult() - Takes a database result set and builds a graph.
 * The first column should be the name, and the second column should be the values
 * Be sure to include HTL_Graphs.php before using this function
 * 
 * @author Tim Perdue tperdue@valinux.com
 * @param		int		The databse result set ID
 * @param		string	The title of the graph
 * 
 */
function GraphResult($result, $title) {
  global $xoopsDB;
	
	$rows = $xoopsDB->getRowsNum($result);

	if ((!$result) || ($rows < 1)) {
		echo 'None Found.';
	} else {
		$names = array();
		$values = array();

		for ($j=0; $j < $xoopsDB->getRowsNum($result); $j++) {
			if (unofficial_getDBResult($result, $j, 0) != '' && unofficial_getDBResult($result, $j, 1) != '' ) {
				$names[$j]= unofficial_getDBResult($result, $j, 0);
				$values[$j]= unofficial_getDBResult($result, $j, 1);
			}
		}

	/*
		This is another function detailed below
	*/
		GraphIt($names,$values,$title);
	}
}

/**
 * GraphIt() - Build a graph
 * 
 * @author Tim Perdue tperdue@valinux.com
 * @param		array	An array of names
 * @param		array	An array of values
 * @param		string	The title of the graph
 *
 */
function GraphIt($name_string,$value_string,$title) {
  global $bgpri;
	
	$counter = count($name_string);

	/*
		Can choose any color you wish
	*/
	$bars = array();

	for ($i = 0; $i < $counter; $i++) {
		$bars[$i] = $bgpri[5];
	}

	$counter = count($value_string);

	/*
		Figure the max_value passed in, so scale can be determined
	*/

	$max_value = 0;

	for ($i = 0; $i < $counter; $i++) {
		if ($value_string[$i] > $max_value) {
			$max_value=$value_string[$i];
		}
	}

	if ($max_value < 1) {
		$max_value=1;
	}

	/*
		I want my graphs all to be 800 pixels wide, so that is my divisor
	*/

	$scale=(400/$max_value);

	/*
		I create a wrapper table around the graph that holds the title
	*/

  echo "<table border='0'>"
	    ."<tr class='bg2'>"
			."<td><b>$title</b></td>"
  	  ."</tr>";

	echo '<TR><TD>';
	/*
		Create an associate array to pass in. I leave most of it blank
	*/

	$vals =  array(
	'vlabel'=>'',
	'hlabel'=>'',
	'type'=>'',
	'cellpadding'=>'',
	'cellspacing'=>'0',
	'border'=>'',
	'width'=>'',
	'background'=>'',
	'vfcolor'=>'',
	'hfcolor'=>'',
	'vbgcolor'=>'',
	'hbgcolor'=>'',
	'vfstyle'=>'',
	'hfstyle'=>'',
	'noshowvals'=>'',
	'scale'=>$scale,
	'namebgcolor'=>'',
	'valuebgcolor'=>'',
	'namefcolor'=>'',
	'valuefcolor'=>'',
	'namefstyle'=>'',
	'valuefstyle'=>'',
	'doublefcolor'=>'');

	/*
		This is the actual call to the HTML_Graphs class
	*/

	html_graph($name_string,$value_string,$bars,$vals);

	echo '
		</TD></TR></TABLE>
		<!-- end outer graph table -->';
}
?>
