<?php
/**
  *
  * Project Admin page to view permissions of the project members
  *
  * This pages shows permissions of all project members as static table,
  * with links to userpermedit.php for editing individual members.
  *
  * Known bugs:
  * 1. This page doesn't show permissions for specific trackers.
  *
  * SourceForge: Breaking Down the Barriers to Open Source Development
  * Copyright 1999-2001 (c) VA Linux Systems
  * http://sourceforge.net
  *
  * @version   $Id: userperms.php,v 1.3 2002/06/07 09:17:34 arjenvanefferen Exp $
  *
  */

include_once ("../../../mainfile.php");

$langfile="project.php";
require_once(XOOPS_ROOT_PATH."/xf/include/pre.php");
require_once(XOOPS_ROOT_PATH."/xf/project/admin/project_admin_utils.php");
require_once(XOOPS_ROOT_PATH."/xf/include/project_summary.php");

project_check_access ($group_id);

// get current information
$group =& group_get_object($group_id);
$perm  =& $group->getPermission( $xoopsUser );

// Maps role id to string
function role_id2str($role_id) {
	global $member_roles_assoc, $xoopsDB;
	if (!$member_roles_assoc) {
		$sql = "SELECT category_id,name FROM ".$xoopsDB->prefix("xf_people_job_category");
		$member_roles = $xoopsDB->query($sql);
		$member_roles_assoc = util_result_columns_to_assoc($member_roles);
	}

	if ($member_roles_assoc[$role_id]) {
		$str = $member_roles_assoc[$role_id];
		if (trim($str)) {
			return $str;
		} 
	}

	return "???";
}

// Render table row of developer's permissions
function show_permissions_row($i, $row_dev) {
	global $group_id;

	// Show admins in bold
	if (stristr($row_dev['admin_flags'],'A')) {
		$name = "<b>".$row_dev['user_name']." (".$row_dev['name'].")</b>";
	} else {
		$name = $row_dev['user_name']." (".$row_dev['name'].")";
	}

	echo "<tr align='center' class='".($i%2>0?"bg1":"bg3")."'>"
	    ."<td align='left'>"
			."<a href='userpermedit.php?group_id=".$group_id
			."&user_id=".$row_dev['user_id']."'>".$name."</a><br>"
			.role_id2str($row_dev['member_role'])
			.($row_dev['release_flags']==1?", "._XF_PRJ_RELTECH:"")."</td>";

	// artifact manager permissions
	$art2perm = array(0=>'-',2=>'A');
	echo "<TD>".$art2perm[$row_dev['artifact_flags']]."</td>";

	// project/task manager permissions
	$flag2perm = array(0=>'-',1=>'T',2=>'A&T',3=>'A');
	echo "<TD>".$flag2perm[$row_dev['project_flags']]."</td>";

	// forum permissions
	$forum2perm = array(0=>'-',2=>_XF_PRJ_MODERATOR);
	echo "<TD>".$forum2perm[$row_dev['forum_flags']]."</td>";

	// documenation manager permissions
	$forum2perm = array(0=>'-',1=>_XF_PRJ_EDITOR);
	echo "<TD>".$forum2perm[$row_dev['doc_flags']]."</td>";

	echo "</TR>";
}

/*
 *	Main Code
 */

$group->clearError();

include ("../../../header.php");
OpenTable();

echo "<b>"._XF_G_PROJECT.": ".$group->getPublicName()."</b><br /><br />";
echo "<B style='font-size:16px;align:left;'>"._XF_PRJ_PROJECTDEVPERMISSIONS."</B><br />";
project_tabs ('admin', $group_id);
project_admin_header($group_id, $perm->isAdmin());

?>

<P>
<p><?php echo _XF_PRJ_CLICKNAMEBELOW; ?></p>
<P>

<table border="0" width="95%" cellpadding="0" cellspacing="0" align="center" valign="top"><tr><td class='bg2'>
<table border="0" cellpadding="4" cellspacing="1" width="100%">
<tr class='bg2' align='left'>
<td align="center"><span class='fg2'><b><?php echo _XF_PRJ_GENERAL; ?></b></span></td>
<td align="center"><span class='fg2'><b><?php echo _XF_PRJ_TRACKERMANAGER; ?></b></span></td>
<td align="center"><span class='fg2'><b><?php echo _XF_PRJ_PROJECTTASKMANAGER; ?></b></span></td>
<td align="center"><span class='fg2'><b><?php echo _XF_G_FORUMS; ?></b></span></td>
<td align="center"><span class='fg2'><b><?php echo _XF_PRJ_DOCMANAGER; ?></b></span></td>
</TR>
<?php

	$res_dev = $xoopsDB->query("SELECT "
	                          ."u.uname AS user_name,"
	                          ."u.name,"
				                    ."u.uid AS user_id," 
				                    ."ug.admin_flags,"
				                    ."ug.forum_flags,"
				                    ."ug.project_flags," 
				                    ."ug.doc_flags,"
				                    ."ug.cvs_flags," 
				                    ."ug.release_flags," 
				                    ."ug.artifact_flags," 
				                    ."ug.member_role "
				                    ."FROM ".$xoopsDB->prefix("users")." u,".$xoopsDB->prefix("xf_user_group")." ug "
				                    ."WHERE "
				                    ."u.uid=ug.user_id AND "
				                    ."ug.group_id='$group_id' "
				                    ."ORDER BY u.uname");
	if (!$res_dev || $xoopsDB->getRowsNum($res_dev) < 1) {
		echo "<H4>"._XF_PRJ_NODEVELOPERSFOUND."</H4>";
	} else {
		$i = 0;

		while ($row_dev = $xoopsDB->fetchArray($res_dev)) {

			show_permissions_row($i++, $row_dev);

		}
	}

?>

</TABLE></td></tr></table>

<?php
CloseTable();
include ("../../../footer.php");
?>
